package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.ProposalInfo;
import com.ruoyi.system.domain.ProposalUnitReply;

/**
 * 提案单位答复Service接口
 * 
 * @author boman
 * @date 2024-03-07
 */
public interface IProposalUnitReplyService 
{
    /**
     * 查询提案单位答复
     * 
     * @param id 提案单位答复主键
     * @return 提案单位答复
     */
    public ProposalUnitReply selectProposalUnitReplyById(Long id);

    /**
     * 查询提案单位答复列表
     * 
     * @param proposalUnitReply 提案单位答复
     * @return 提案单位答复集合
     */
    public List<ProposalUnitReply> selectProposalUnitReplyList(ProposalUnitReply proposalUnitReply);

    /**
     * 新增提案单位答复
     * 
     * @param proposalUnitReply 提案单位答复
     * @return 结果
     */
    public int insertProposalUnitReply(ProposalUnitReply proposalUnitReply);

    /**
     * 修改提案单位答复
     * 
     * @param proposalUnitReply 提案单位答复
     * @return 结果
     */
    public int updateProposalUnitReply(ProposalUnitReply proposalUnitReply);

    /**
     * 批量删除提案单位答复
     * 
     * @param ids 需要删除的提案单位答复主键集合
     * @return 结果
     */
    public int deleteProposalUnitReplyByIds(Long[] ids);

    /**
     * 删除提案单位答复信息
     * 
     * @param id 提案单位答复主键
     * @return 结果
     */
    public int deleteProposalUnitReplyById(Long id);

    AjaxResult reply(ProposalUnitReply proposalUnitReply);
}
